
// There are lots of ways to do this technique
// Here we can apply an eventListener to the
// nav and use the event.target to see what
// child button was clicked.

// If you are not familiar with JS arrow functions, go
// to the bottom of this file for an explanation.

// select nav element
const nav = document.querySelector('.style-switcher');
const body = document.body;

nav.addEventListener('click', e => {

  // remove previous styles if any...
  body.classList = '';

  // add to the body the class of the clicked button
  // This could be more elegant. But it's certainly quick!

  body.classList.add(e.target.classList);

});


// ANOTHER way we could do it. Adding eventListener to
// all the buttons. To test, uncomment this and comment out
// the JS above this.

// const buttons = document.querySelectorAll('nav button');
// const body = document.body;
// console.log(buttons);
//
// buttons.forEach( button => button.addEventListener('click', swapStyles));
//
// function swapStyles(e){
//   body.classList = '';
//   body.classList.add(e.target.classList);
// }



// JS ARROW FUNCTION SYNTAX
// In the exercise on adding multiple event listeners
// ( http://wrmf.ca/posts/javascript-adding-eventlisteners-to-multiple-items/ ),
// I used both traditional function syntax and modern arrow syntax.
//
// Here was the example used:
//
// buttons.forEach(function(button){
//   button.addEventListener('click', changeTheColor);
// });
//
// buttons.forEach( button => button.addEventListener('click',changeTheColor));
//
// To understand the difference in this invocation of forEach, break down what
// is happening in the first, traditional one:
//
// - we pass a function as an argument to the forEach method
// - inside that function, we pass "button". This is a variable referring
//   to each button in turn as we iterate through the BUTTONS nodeList.
// - To the button on each pass, we add an eventListener.
//
// The arrow function syntax does the same thing, but it is more
// concise. We don't even need to include the word FUNCTION.
// Instead, we start by passing BUTTON, which is a variable representing
// the single button each time through the iteration.
//
// Then after the => we put what normally would go inside the {} of
// a function.
//
// In fact, if we need multiple lines for the function body, we would
// need to use the curly braces.
//
// For example,
//
// buttons.forEach( button => {
//   button.addEventListener('click',changeTheColor);
//   console.log(button);
//   console.log('i love buttons, etc');
// });
